%from Brian Dushaw: http://staff.washington.edu/dushaw/WOA/
%modified by Boss @UMAINE 9/2012
clear all
close all

lat=[-15 -20];
lon=[148 148];
%[These are two positions in the North Atlantic. The programs will secretly convert the negative longitudes to positive longitudes by adding 360; this is something to be a little careful about. The negative values will be returned.]

[r, glat, glon]=dist(lat,lon,50); %[Get 50 points on a path between the two positions (WGS 1984 is the default).]
[P1,z]=getlev(glat,glon,'c'); 
[P2,z]=getlev(glat,glon,'T'); 
[P3,z]=getlev(glat,glon,'S'); 
%[Gets the World Ocean Atlas sound speed (P1) and temperature (P2) profiles (at the 33 standard depths) on those 50 points and writes them to a file "templev.ssp". (The file is overwritten by the second call). Sound speed and depth are reported back in P1 and z, respectively. P1, P2 are 33X50 matrices.]
figure(1); plot(P1,-z/1000); xlabel('Sound Speed (m/s)'); ylabel('Depth (km)') 
figure(2); plot(P2,-z/1000); xlabel('Temperature \circC'); ylabel('Depth (km)') 
figure(3); plot(P3,-z/1000); xlabel('Salinity (ptt)'); ylabel('Depth (km)') 
figure(4); contourf(glat,-z/1000,P1); xlabel('Latitude'); ylabel('Depth (km)'); title('Sound Speed')
colorbar


%Here is a color map of sound speed at 300 m depth. It shows the effects of filling in sound speed values over land masses by nearest-neighbor values. The code fragment to make this figure, which will also show the format of the data files, is:

load lev_ann.mat %[Loads in c]
load lev_latlonZ.mat %[Loads in lat, lon, z]
figure;
worldmap([0 360 -90 90])
hold on
plot([lat],[lon],'b*')
lat1=reshape(lat,360,180)*0.1;
lon1=reshape(lon,360,180)*0.1; 
cc=1000+reshape(c(:,12),360,180)/100;% depth 12 is 300 m
surf(lon1,lat1,cc); 
shading flat; 
view([0 90])
colorbar

%export mean sound speed profile
cc=median(P1');
A=[z; cc]';
save mean_c_profile.txt A -ascii